@@ -11,12 +11,15 @@ dWARING<-function (x, mu=2, sigma=2, log = FALSE)
     	stop(paste("sigma must be > 0", "\n", ""))
     if (any(x < 0))
         stop(paste("x must be >=0", "\n", ""))
-    b <- 1+(1/sigma)
-    n <- mu*(b-1)
-    # fx <- beta(n+x, b+1)/beta(n,b)
-    fx <- lbeta(n+x, b+1)-lbeta(n,b)
-    fx <- if(log) fx else exp(fx) 
-    fx
+     ly <- max(length(x),length(mu),length(sigma)) 
+      x <- rep(x, length = ly)      
+  sigma <- rep(sigma, length = ly)
+     mu <- rep(mu, length = ly)   
+      b <- 1+(1/sigma)
+      n <- mu*(b-1)
+     fx <- lbeta(n+x, b+1)-lbeta(n,b)
+     fx <- if(log) fx else exp(fx) 
+     fx
 }
 
 
@@ -29,10 +32,10 @@ pWARING<-function (q,  mu=2, sigma=2,  lower.tail = TRUE, log.p = FALSE)
     	stop(paste("sigma must be > 0", "\n", ""))
     if (any(q < 0))
         stop(paste("q must be >=0", "\n", ""))
-    ly <- max(length(q), length(mu), length(sigma))
-    q <- rep(q, length = ly)
-    mu<- rep(mu, length = ly)
-    sigma<- rep(sigma, length = ly)
+     ly <- max(length(q), length(mu), length(sigma))
+      q <- rep(q, length = ly)
+     mu <- rep(mu, length = ly)
+  sigma <- rep(sigma, length = ly)
     #s1<- seq(0, max(q))
     #cdf<- cumsum(dWAR(s1, mu=mu, sigma=sigma))
     #s2<-match(q,s1,nomatch=0)
